package gonganxitong

import (
	"shylinux.com/x/ice"
	kit "shylinux.com/x/toolkits"

	"shylinux.com/x/community/src/gonganxitong/model"
)

type order struct {
	Table
	user      user
	apply     apply
	userPlace userPlace
	place     place
	street    street
	city      city
	event     event
	portal    string `data:"true"`
	create    string `name:"create user_uid* apply_uid* status*"`
	reject    string `name:"reject" role:"void"`
	approve   string `name:"approve" role:"void"`
}

func (s order) Create(m *ice.Message, arg ...string) {
	s.Table.Create(m, arg...)
	s.SendTemplate(m, m.Option(model.USER_UID), "场所权限审批 请处理")
}
func (s order) Reject(m *ice.Message, arg ...string) {
	defer m.ToastProcess()()
	defer s.event.Record(m, kit.Format("审批驳回%s成为%s", m.Option(model.USER_NAME), m.Option(model.USER_PLACE_ROLE)), m.Option(model.UID))
	m.Cmd(s.apply, s.apply.Reject, m.Option(model.UID))
	s.Table.Update(m, kit.Dict(model.STATUS, OrderRejected), model.UID, m.Option(model.ORDER_UID))
	s.SendTemplate(m, m.Option(model.USER_UID), "场所权限审批 已驳回 ❌")
}
func (s order) Approve(m *ice.Message, arg ...string) {
	defer m.ToastProcess()()
	defer s.event.Record(m, kit.Format("审批通过%s成为%s", m.Option(model.USER_NAME), m.Option(model.USER_PLACE_ROLE)), m.Option(model.UID))
	m.Cmd(s.apply, s.apply.Approve, m.Option(model.UID))
	s.Table.Update(m, kit.Dict(model.STATUS, OrderApproved), model.UID, m.Option(model.ORDER_UID))
	s.SendTemplate(m, m.Option(model.USER_UID), "场所权限审批 已通过 ✅")
}
func (s order) List(m *ice.Message, arg ...string) {
	s.Tables(m, s.apply, "left join users on applies.user_uid = users.uid", s.place, s.street, s.city).Fields(m,
		s.Key(s, model.CREATED_AT), s.Key(s, model.ID),
		model.USER_AVATAR, model.USER_NAME,
		model.PLACE_NAME, model.PLACE_TYPE, s.AS(s.Key(s.apply, model.ROLE), model.USER_PLACE_ROLE), model.ORDER_STATUS,
		model.CITY_NAME, model.STREET_NAME, model.PLACE_ADDRESS,
		model.BEGIN_TIME, model.END_TIME,
		s.Key(s.apply, model.UID), s.AS(s.Key(s, model.UID), model.ORDER_UID), model.PLACE_UID,
	).Orders(m, s.Desc(model.CREATED_AT))
	if len(arg) == 0 {
		if m.IsTech() {
			s.Table.Select(m)
		} else {
			s.Table.Select(m, s.Key(s, model.USER_UID), m.Option(model.USER_UID))
		}
	} else if len(arg) == 1 {
		s.Table.Select(m, s.Key(s, model.USER_UID), m.Option(model.USER_UID), model.PLACE_UID, arg[0])
		defer m.Sort(kit.Fields(model.ORDER_STATUS, model.CREATED_AT), []string{OrderCreate.String(), OrderApproved.String(), OrderRejected.String()}, ice.STR_R)
	} else {
		s.Table.Select(m.FieldsSetDetail(), s.Key(s, model.USER_UID), m.Option(model.USER_UID), s.Key(s.apply, model.UID), arg[1])
	}
	m.Table(func(value ice.Maps) {
		switch OrderStatus(kit.Int(value[model.ORDER_STATUS])) {
		case OrderCreate:
			m.PushButton(s.Reject, s.Approve)
		default:
			m.PushButton()
		}
	})
	m.Info("what %v", m.FormatsMeta(nil))
	s.RewriteAppend(m).Display("").DisplayCSS("")

}
func init() { ice.TeamCtxCmd(order{}) }

type OrderStatus int

const (
	OrderCreate OrderStatus = iota
	OrderRejected
	OrderApproved
)

var OrderStatusList = map[OrderStatus]string{
	OrderCreate:   "create",
	OrderRejected: "rejected",
	OrderApproved: "approved",
}

func (s OrderStatus) String() string { return OrderStatusList[s] }
